@@ -25,7 +25,9 @@ from .exceptions import (
     ServerError,
     SpecialError,
     TooLarge,
+    TooManyRequests,
     UnavailableForLegalReasons,
+    URITooLong,
 )
 from .rate_limit import RateLimiter
 from .util import authorization_error_class
@@ -100,7 +102,9 @@ class Session(object):
         codes["media_type"]: SpecialError,
         codes["not_found"]: NotFound,
         codes["request_entity_too_large"]: TooLarge,
+        codes["request_uri_too_large"]: URITooLong,
         codes["service_unavailable"]: ServerError,
+        codes["too_many_requests"]: TooManyRequests,
         codes["unauthorized"]: authorization_error_class,
         codes["unavailable_for_legal_reasons"]: UnavailableForLegalReasons,
         # Cloudflare status (not named in requests)
